@@ -26,7 +26,7 @@ DEFCACHE = ENV['HOME'] + '/.feed2imap.cache'
 
 # Feed2imap configuration
 class F2IConfig
-  attr_reader :imap_accounts, :cache, :feeds, :dumpdir
+  attr_reader :imap_accounts, :cache, :feeds, :dumpdir, :updateddebug
 
   # Load the configuration from the IO stream
   # TODO should do some sanity check on the data read.
@@ -36,6 +36,7 @@ class F2IConfig
     @dumpdir = @conf['dumpdir'] || nil
     @conf['feeds'] ||= []
     @feeds = []
+    @updateddebug =  (@conf['debug-updated'] and @conf['debug-updated'] != 'false')
     @imap_accounts = ImapAccounts::new
     @conf['feeds'].each do |f|
       if f['disable'].nil?
@@ -70,7 +71,7 @@ end
 
 # A configured feed. simple data container.
 class ConfigFeed
-  attr_reader :name, :url, :imapaccount, :folder
+  attr_reader :name, :url, :imapaccount, :folder, :always_new
   attr_accessor :body
 
   def initialize(f, imapaccount, folder)
@@ -79,6 +80,7 @@ class ConfigFeed
     @url.sub!(/^feed:/, '') if @url =~ /^feed:/
     @imapaccount, @folder = imapaccount, folder
     @freq = f['min-frequency']
+    @always_new =  (f['always-new'] and f['always-new'] != 'false')
     @freq = @freq.to_i if @freq
   end
 
