@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =end
 
 # Feed2Imap version
-F2I_VERSION = '0.7'
+F2I_VERSION = '0.8'
 
 require 'feed2imap/config'
 require 'feed2imap/cache'
@@ -61,12 +61,12 @@ class Feed2Imap
     end
     # init cache
     @logger.info('Initializing cache')
-    @cache = ItemCache::new
+    @cache = ItemCache::new(@config.updateddebug)
     if not File::exist?(@config.cache + '.lock')
       f = File::new(@config.cache + '.lock', 'w')
       f.close
     end
-    if File::new(@config.cache + '.lock').flock(File::LOCK_EX | File::LOCK_NB) == false
+    if File::new(@config.cache + '.lock', 'w').flock(File::LOCK_EX | File::LOCK_NB) == false
       @logger.fatal("Another instance of feed2imap is already locking the cache file")
       exit(1)
     end
@@ -145,7 +145,7 @@ class Feed2Imap
         next
       end
       begin
-        newitems, updateditems = @cache.get_new_items(f.name, feed.items)
+        newitems, updateditems = @cache.get_new_items(f.name, feed.items, f.always_new)
       rescue
         @logger.fatal("Exception caught when selecting new items for #{f.name}: #{$!}")
         puts $!.backtrace
@@ -187,7 +187,7 @@ class Feed2Imap
       begin
         ac.disconnect
       rescue
-        @logger.fatal("Exception caught while closing connection to #{ac.to_s}: #{$!}")
+        @logger.info("Exception caught while closing connection to #{ac.to_s}: #{$!}")
       end
     end
   end
