@@ -284,7 +284,11 @@ module Net
 
     # Disconnects from the server.
     def disconnect
-      @sock.shutdown unless @usessl
+      if @usessl
+        @sock.to_io.shutdown
+      else
+        @sock.shutdown
+      end
       @receiver_thread.join
       @sock.close
     end
